@@ -108,27 +108,27 @@ cv_varsel.default <- function(object, ...) {
 #' @rdname cv_varsel
 #' @export
 cv_varsel.refmodel <- function(
-  object,
-  method = NULL,
-  cv_method = if (!inherits(object, "datafit")) "LOO" else "kfold",
-  ndraws = NULL,
-  nclusters = 20,
-  ndraws_pred = 400,
-  nclusters_pred = NULL,
-  refit_prj = !inherits(object, "datafit"),
-  nterms_max = NULL,
-  penalty = NULL,
-  verbose = TRUE,
-  nloo = NULL,
-  K = if (!inherits(object, "datafit")) 5 else 10,
-  lambda_min_ratio = 1e-5,
-  nlambda = 150,
-  thresh = 1e-6,
-  regul = 1e-4,
-  validate_search = TRUE,
-  seed = sample.int(.Machine$integer.max, 1),
-  search_terms = NULL,
-  ...
+    object,
+    method = NULL,
+    cv_method = if (!inherits(object, "datafit")) "LOO" else "kfold",
+    ndraws = NULL,
+    nclusters = 20,
+    ndraws_pred = 400,
+    nclusters_pred = NULL,
+    refit_prj = !inherits(object, "datafit"),
+    nterms_max = NULL,
+    penalty = NULL,
+    verbose = TRUE,
+    nloo = NULL,
+    K = if (!inherits(object, "datafit")) 5 else 10,
+    lambda_min_ratio = 1e-5,
+    nlambda = 150,
+    thresh = 1e-6,
+    regul = 1e-4,
+    validate_search = TRUE,
+    seed = sample.int(.Machine$integer.max, 1),
+    search_terms = NULL,
+    ...
 ) {
   # Set seed, but ensure the old RNG state is restored on exit:
   if (exists(".Random.seed", envir = .GlobalEnv)) {
@@ -138,6 +138,8 @@ cv_varsel.refmodel <- function(
   set.seed(seed)
 
   refmodel <- object
+  # Needed to avoid a warning when calling varsel() later:
+  search_terms_usr <- search_terms
   ## resolve the arguments similar to varsel
   args <- parse_args_varsel(
     refmodel = refmodel, method = method, refit_prj = refit_prj,
@@ -189,7 +191,8 @@ cv_varsel.refmodel <- function(
                   refit_prj = refit_prj, nterms_max = nterms_max - 1,
                   penalty = penalty, verbose = verbose,
                   lambda_min_ratio = lambda_min_ratio, nlambda = nlambda,
-                  regul = regul, search_terms = search_terms, seed = seed, ...)
+                  regul = regul, search_terms = search_terms_usr, seed = seed,
+                  ...)
   } else if (cv_method == "LOO") {
     sel <- sel_cv$sel
   }
