@@ -22,6 +22,9 @@ test_that(paste(
       method_expected = meth_exp_crr,
       nprjdraws_search_expected = args_vs[[tstsetup]]$nclusters,
       nprjdraws_eval_expected = args_vs[[tstsetup]]$nclusters_pred,
+      search_trms_empty_size =
+        length(args_vs[[tstsetup]]$search_terms) &&
+        all(grepl("\\+", args_vs[[tstsetup]]$search_terms)),
       info_str = tstsetup
     )
   }
@@ -91,24 +94,10 @@ test_that("`d_test` works", {
       type = "test",
       offset = refmod_crr$offset
     )
-    # We expect a warning which in fact should be suppressed, though (see
-    # issue #162):
-    warn_expected <- if (pkg_crr == "rstanarm" &&
-                         mod_crr == "glm" &&
-                         grepl("\\.with_offs", tstsetup)) {
-      paste("^'offset' argument is NULL but it looks like you estimated the",
-            "model using an offset term\\.$")
-    } else {
-      NA
-    }
-    expect_warning(
-      vs_repr <- do.call(varsel, c(
-        list(object = refmod_crr, d_test = d_test_crr),
-        excl_nonargs(args_vs_i)
-      )),
-      warn_expected,
-      info = tstsetup
-    )
+    vs_repr <- do.call(varsel, c(
+      list(object = refmod_crr, d_test = d_test_crr),
+      excl_nonargs(args_vs_i)
+    ))
     meth_exp_crr <- args_vs_i$method
     if (is.null(meth_exp_crr)) {
       meth_exp_crr <- ifelse(mod_crr == "glm", "L1", "forward")
@@ -121,6 +110,9 @@ test_that("`d_test` works", {
       method_expected = meth_exp_crr,
       nprjdraws_search_expected = args_vs_i$nclusters,
       nprjdraws_eval_expected = args_vs_i$nclusters_pred,
+      search_trms_empty_size =
+        length(args_vs_i$search_terms) &&
+        all(grepl("\\+", args_vs_i$search_terms)),
       info_str = tstsetup
     )
     expect_identical(vs_repr$d_test, d_test_crr, info = tstsetup)
@@ -228,6 +220,12 @@ test_that(paste(
   for (tstsetup in tstsetups) {
     args_vs_i <- args_vs[[tstsetup]]
     m_max <- args_vs_i$nterms_max + 1L
+    if (length(args_vs_i$search_terms) &&
+        all(grepl("\\+", args_vs_i$search_terms))) {
+      # This is the "empty_size" setting, so we have to subtract the skipped
+      # model size (see issue #307):
+      m_max <- m_max - 1L
+    }
     ncl_crr <- args_vs_i$nclusters
     ssq_regul_sel_alpha <- array(dim = c(length(regul_tst), m_max, ncl_crr))
     ssq_regul_sel_beta <- array(dim = c(length(regul_tst), m_max, ncl_crr))
@@ -248,6 +246,9 @@ test_that(paste(
           method_expected = "forward",
           nprjdraws_search_expected = args_vs_i$nclusters,
           nprjdraws_eval_expected = args_vs_i$nclusters_pred,
+          search_trms_empty_size =
+            length(args_vs_i$search_terms) &&
+            all(grepl("\\+", args_vs_i$search_terms)),
           info_str = tstsetup
         )
       }
@@ -387,7 +388,7 @@ test_that("for L1 search, `penalty` has an expected effect", {
     penal_crr[idx_penal_Inf] <- Inf
     # TODO: This test should be extended to also test the case where a
     # categorical predictor (more precisely, one of its dummy variables) gets
-    # zero or infinite penalty. Until then, the following check ensures that no
+    # zero or infinite penalty. For now, the following check ensures that no
     # categorical predictors get zero or infinite penalty:
     stopifnot(all(grep("^xca\\.", penal_possbl) >= max(c(idx_penal_0,
                                                          idx_penal_Inf))))
@@ -419,6 +420,58 @@ test_that("for L1 search, `penalty` has an expected effect", {
   }
 })
 
+# search_terms ------------------------------------------------------------
+
+test_that(paste(
+  "including all terms in `search_terms` gives the same results as the default",
+  "`search_terms`"
+), {
+  skip_if_not(run_vs)
+  tstsetups <- grep("\\.alltrms", names(vss), value = TRUE)
+  for (tstsetup in tstsetups) {
+    tstsetup_default <- sub("\\.alltrms", "\\.default_search_trms", tstsetup)
+    if (!tstsetup_default %in% names(vss)) next
+    expect_identical(vss[[tstsetup]], vss[[tstsetup_default]], info = tstsetup)
+  }
+})
+
+test_that(paste(
+  "forcing the inclusion of a term in the candidate models via `search_terms`",
+  "works as expected"
+), {
+  skip_if_not(run_vs)
+  tstsetups <- grep("\\.fixed", names(vss), value = TRUE)
+  for (tstsetup in tstsetups) {
+    # In principle, `search_trms_tst$fixed$search_terms[1]` could be used
+    # instead of `"xco.1"`, but that would seem like the forced term always has
+    # to come first in `search_terms` (which is not the case):
+    expect_identical(solution_terms(vss[[tstsetup]])[1], "xco.1",
+                     info = tstsetup)
+  }
+})
+
+test_that(paste(
+  "forcing the exclusion of a term in the candidate models via `search_terms`",
+  "works as expected"
+), {
+  skip_if_not(run_vs)
+  tstsetups <- grep("\\.excluded", names(vss), value = TRUE)
+  for (tstsetup in tstsetups) {
+    expect_false("xco.1" %in% solution_terms(vss[[tstsetup]]), info = tstsetup)
+  }
+})
+
+test_that(paste(
+  "forcing the skipping of a model size via `search_terms` works as expected"
+), {
+  skip_if_not(run_vs)
+  tstsetups <- grep("\\.empty_size", names(vss), value = TRUE)
+  for (tstsetup in tstsetups) {
+    expect_true(all(grepl("\\+", solution_terms(vss[[tstsetup]]))),
+                info = tstsetup)
+  }
+})
+
 # cv_varsel() -------------------------------------------------------------
 
 context("cv_varsel()")
@@ -445,6 +498,9 @@ test_that(paste(
       valsearch_expected = args_cvvs[[tstsetup]]$validate_search,
       nprjdraws_search_expected = args_cvvs[[tstsetup]]$nclusters,
       nprjdraws_eval_expected = args_cvvs[[tstsetup]]$nclusters_pred,
+      search_trms_empty_size =
+        length(args_cvvs[[tstsetup]]$search_terms) &&
+        all(grepl("\\+", args_cvvs[[tstsetup]]$search_terms)),
       info_str = tstsetup
     )
   }
@@ -571,6 +627,9 @@ test_that("setting `nloo` smaller than the number of observations works", {
       nprjdraws_search_expected = args_cvvs_i$nclusters,
       nprjdraws_eval_expected = args_cvvs_i$nclusters_pred,
       nloo_expected = nloo_tst,
+      search_trms_empty_size =
+        length(args_cvvs_i$search_terms) &&
+        all(grepl("\\+", args_cvvs_i$search_terms)),
       info_str = tstsetup
     )
     # Expected equality for most components with a few exceptions:
@@ -623,6 +682,9 @@ test_that("`validate_search` works", {
       valsearch_expected = FALSE,
       nprjdraws_search_expected = args_cvvs_i$nclusters,
       nprjdraws_eval_expected = args_cvvs_i$nclusters_pred,
+      search_trms_empty_size =
+        length(args_cvvs_i$search_terms) &&
+        all(grepl("\\+", args_cvvs_i$search_terms)),
       info_str = tstsetup
     )
     # Expected equality for most components with a few exceptions:
@@ -756,23 +818,10 @@ test_that(paste(
     refmod_crr <- get_refmodel(fit_crr, cvfits = kfold_obj)
 
     # Run cv_varsel():
-    # We expect a warning which in fact should be suppressed, though (see
-    # issue #162):
-    warn_expected <- if (mod_crr == "glm" &&
-                         grepl("\\.with_offs", tstsetup)) {
-      paste("^'offset' argument is NULL but it looks like you estimated the",
-            "model using an offset term\\.$")
-    } else {
-      NA
-    }
-    expect_warning(
-      cvvs_cvfits <- do.call(cv_varsel, c(
-        list(object = refmod_crr),
-        excl_nonargs(args_cvvs_i, nms_excl_add = "K")
-      )),
-      warn_expected,
-      info = tstsetup
-    )
+    cvvs_cvfits <- do.call(cv_varsel, c(
+      list(object = refmod_crr),
+      excl_nonargs(args_cvvs_i, nms_excl_add = "K")
+    ))
 
     # Checks:
     vsel_tester(
@@ -785,6 +834,9 @@ test_that(paste(
       valsearch_expected = args_cvvs_i$validate_search,
       nprjdraws_search_expected = args_cvvs_i$nclusters,
       nprjdraws_eval_expected = args_cvvs_i$nclusters_pred,
+      search_trms_empty_size =
+        length(args_cvvs_i$search_terms) &&
+        all(grepl("\\+", args_cvvs_i$search_terms)),
       info_str = tstsetup
     )
     # Expected equality for some components:
@@ -887,6 +939,9 @@ test_that(paste(
       valsearch_expected = args_cvvs_i$validate_search,
       nprjdraws_search_expected = args_cvvs_i$nclusters,
       nprjdraws_eval_expected = args_cvvs_i$nclusters_pred,
+      search_trms_empty_size =
+        length(args_cvvs_i$search_terms) &&
+        all(grepl("\\+", args_cvvs_i$search_terms)),
       info_str = tstsetup
     )
     # Expected equality for some components:
